% This function computes the posterior mean for the LNWS method. 
%
% Input
%  x -- observed wavelet coefficient
%  eps -- values of hyperparameter eps_j
%  b -- values of hyperparameter b
%
% Output
%  br -- posterior mean, shrunk version of observed wavelet coefficient
% -------------------------------------------------------------------------
function [br] = bayesrule_lnws(x,eps,b)

f0 = 1/(gamma(3/2)*2^(3/2))*x^(1/2)*exp(-x/2);
m = b/sqrt(1+2*b)*exp(-b*x/(1+2*b))*(2*normcdf(sqrt(x/(1+2*b)))-1);
mar = eps*f0+(1-eps)*m;
p = eps*f0 / mar;

br = (1-p)/(1+2*b)^2 * (1+2*b+x+ exp(-x/(2+4*b))*sqrt(2/pi)*sqrt(x+2*b*x)/(2*normcdf(sqrt(x/(1+2*b)))-1) );  
